@@ -16,6 +16,7 @@ from rsatoolbox.util.descriptor_utils import num_index
 from rsatoolbox.util.descriptor_utils import subset_descriptor
 from rsatoolbox.util.descriptor_utils import check_descriptor_length_error
 from rsatoolbox.util.descriptor_utils import append_descriptor
+from rsatoolbox.util.descriptor_utils import dict_to_list
 from rsatoolbox.util.data_utils import extract_dict
 from rsatoolbox.util.file_io import write_dict_hdf5
 from rsatoolbox.util.file_io import write_dict_pkl
@@ -372,14 +373,26 @@ class RDMs:
 
         Pass keyword arguments that correspond to descriptors,
         with value indicating the sort type. Supported methods:
+
             'alpha': sort alphabetically (using np.sort)
+
             list/np.array: specify the new order explicitly. Values should
                 correspond to the descriptor values
 
-        Example:
-            Sorts the condition descriptor alphabetically:
+        Examples:
 
-            `rdms.sort(condition='alpha')`
+            The following code sorts the 'condition' descriptor alphabetically:
+
+            ::
+
+                rdms.sort_by(condition='alpha')
+
+            The following code sort the 'condition' descriptor in the order
+            1, 3, 2, 4, 5:
+
+            ::
+
+                rdms.sort_by(condition=[1, 3, 2, 4, 5])
 
         Raises:
             ValueError: Raised if the method chosen is not implemented
@@ -400,7 +413,6 @@ class RDMs:
             else:
                 raise ValueError(f'Unknown sorting method: {method}')
 
-
     def mean(self, weights=None):
         """Average rdm of all rdms contained
 
@@ -414,9 +426,9 @@ class RDMs:
             `rsatoolbox.rdm.rdms.RDMs`: New RDMs object with one vector
         """
         if str(weights) in self.rdm_descriptors:
-            new_descriptors = dict(
-                [(k, v) for (k, v) in self.descriptors.items() if k != weights]
-            )
+            new_descriptors = {
+                (k, v) for (k, v) in self.descriptors.items() if k != weights
+            }
             weights = self.rdm_descriptors[weights]
         else:
             new_descriptors = deepcopy(self.descriptors)
@@ -440,8 +452,8 @@ def rdms_from_dict(rdm_dict):
     """
     rdms = RDMs(dissimilarities=rdm_dict['dissimilarities'],
                 descriptors=rdm_dict['descriptors'],
-                rdm_descriptors=rdm_dict['rdm_descriptors'],
-                pattern_descriptors=rdm_dict['pattern_descriptors'],
+                rdm_descriptors=dict_to_list(rdm_dict['rdm_descriptors']),
+                pattern_descriptors=dict_to_list(rdm_dict['pattern_descriptors']),
                 dissimilarity_measure=rdm_dict['dissimilarity_measure'])
     return rdms
 
@@ -468,7 +480,7 @@ def load_rdm(filename, file_type=None):
     return rdms_from_dict(rdm_dict)
 
 
-def concat(rdms):
+def concat(*rdms):
     """ concatenates rdm objects
     requires that the rdms have the same shape
     descriptor and pattern descriptors are taken from the first rdms object
@@ -476,15 +488,24 @@ def concat(rdms):
     the rdm index is reinitialized
 
     Args:
-        rdms(list of rsatoolbox.rdm.RDMs): RDMs objects to be concatenated
+        rdms(iterable of pyrsa.rdm.RDMs): RDMs objects to be concatenated
+        or multiple RDMs as separate arguments
 
     Returns:
         rsatoolbox.rdm.RDMs: concatenated rdms object
 
     """
-    rdm = rdms[0]
-    assert isinstance(rdm, RDMs), 'rdms should be a list of RDMs objects'
-    for rdm_new in rdms[1:]:
+    if len(rdms) == 1:
+        if isinstance(rdms[0], RDMs):
+            rdms_list = [rdms[0]]
+        else:
+            rdms_list = list(rdms[0])
+    else:
+        rdms_list = list(rdms)
+    rdm = deepcopy(rdms_list[0])
+    assert isinstance(rdm, RDMs), \
+        'Supply list of RDMs objects, or RDMs objects as separate arguments'
+    for rdm_new in rdms_list[1:]:
         rdm.append(rdm_new)
     return rdm
 
