@@ -1,5 +1,5 @@
 from .rdm_plot import show_rdm, show_rdm_panel, add_descriptor_x_labels, add_descriptor_y_labels
-from .mds_plot import mds, rdm_dimension_reduction
+from .scatter_plot import show_scatter, show_2d, show_MDS, show_tSNE, show_iso
 from .model_plot import plot_model_comparison
 from .icon import Icon
 from .icon import icons_from_folder
