@@ -8,9 +8,9 @@ import warnings
 import numpy as np
 import scipy.stats
 import matplotlib.pyplot as plt
-import matplotlib.patches as patches
+from matplotlib import patches
 from matplotlib.path import Path
-import matplotlib.transforms as transforms
+from matplotlib import transforms
 from matplotlib import cm
 import networkx as nx
 from networkx.algorithms.clique import find_cliques as maximal_cliques
@@ -37,95 +37,165 @@ def plot_model_comparison(result, sort=False, colors=None,
     for bootstrap samples and crossvalidation folds. These are used here to
     construct confidence intervals and perform the significance tests.
 
-    Args (All strings case insensitive):
+    All string inputs are case insensitive.
+
+    Args:
         result (rsatoolbox.inference.result.Result):
             model evaluation result
+
         sort (Boolean or string):
+
             False (default): plot bars in the order passed
+
             'descend[ing]': plot bars in descending order of model performance
+
             'ascend[ing]': plot bars in ascending order of model performance
+
         colors (list of lists, numpy array, matplotlib colormap):
-            None (default): default blue for all bars
-            single color: list or numpy array of 3 or 4 values (RGB, RGBA)
-                    specifying the color for all bars
-            multiple colors: list of lists or numpy array (number of colors by
-                    3 or 4 channels -- RGB, RGBA). If the number of colors
-                    matches the number of models, each color is used for the
-                    bar corresponding to one model (in the order of the models
-                    as passed). If the number of colors does not match the
-                    number of models, the list is linearly interpolated to
-                    assign a color to each model (in the order of the models as
-                    passed). For example, two colors will become a gradation,
-                    unless there are exactly two model. Instead of a list of
-                    lists or numpy array, a matplotlib colormap object may also
-                    be passed (e.g. colors = cm.coolwarm).
+
+            None (default):
+                default blue for all bars
+
+            single color:
+                list or numpy array of 3 or 4 values (RGB, RGBA)
+                specifying the color for all bars
+
+            multiple colors:
+                list of lists or numpy array (number of colors by
+                3 or 4 channels -- RGB, RGBA). If the number of colors
+                matches the number of models, each color is used for the
+                bar corresponding to one model (in the order of the models
+                as passed). If the number of colors does not match the
+                number of models, the list is linearly interpolated to
+                assign a color to each model (in the order of the models as
+                passed). For example, two colors will become a gradation,
+                unless there are exactly two model. Instead of a list of
+                lists or numpy array, a matplotlib colormap object may also
+                be passed (e.g. colors = cm.coolwarm).
+
         alpha (float):
             significance threshold (p threshold or FDR q threshold)
+
         test_pair_comparisons (Boolean or string):
-            False or None: do not plot pairwise model comparison results
-            True (default): plot pairwise model comparison results using
+
+            False or None:
+                do not plot pairwise model comparison results
+
+            True (default):
+                plot pairwise model comparison results using
                 default settings
-            'arrows': plot results in arrows style, indicating pairs of sets
+
+            'arrows':
+                plot results in arrows style, indicating pairs of sets
                 between which all differences are significant
-            'nili': plot results as Nili bars (Nili et al. 2014), indicating
+
+            'nili':
+                plot results as Nili bars (Nili et al. 2014), indicating
                 each significant difference by a horizontal line (or each
                 nonsignificant difference if the string contains a '2', e.g.
                 'nili2')
-            'golan': plot results as Golan wings (Golan et al. 2020), with one
+
+            'golan':
+                plot results as Golan wings (Golan et al. 2020), with one
                 wing (graphical element) indicating all dominance relationships
                 for one model.
+
             'cliques': plot results as cliques of insignificant differences
+
         multiple_pair_testing (Boolean or string):
-            False or 'none': do not adjust for multiple testing for the
+
+            False or 'none':
+                do not adjust for multiple testing for the
                 pairwise model comparisons
-            'FDR' or 'fdr' (default): control the false-discorvery rate at
+
+            'FDR' or 'fdr' (default):
+                control the false-discorvery rate at
                 q = alpha
-            'FWER',' fwer', or 'Bonferroni': control the familywise error rate
-            using the Bonferroni method
+
+            'FWER',' fwer', or 'Bonferroni':
+                control the familywise error rate
+                using the Bonferroni method
+
         test_above_0 (Boolean or string):
-            False or None: do not plot results of statistical comparison of
+
+            False or None:
+                do not plot results of statistical comparison of
                 each model performance against 0
-            True (default): plot results of statistical comparison of each
+
+            True (default):
+                plot results of statistical comparison of each
                 model performance against 0 using default settings ('dewdrops')
-            'dewdrops': place circular "dewdrops" at the baseline to indicate
+
+            'dewdrops':
+                place circular "dewdrops" at the baseline to indicate
                 models whose performance is significantly greater than 0
-            'icicles': place triangular "icicles" at the baseline to indicate
+
+            'icicles':
+                place triangular "icicles" at the baseline to indicate
                 models whose performance is significantly greater than 0
+
             Tests are one-sided, use the global alpha threshold and are
             automatically Bonferroni-corrected for the number of models tested.
+
         test_below_noise_ceil (Boolean or string):
-            False or None: do not plot results of statistical comparison of
+
+            False or None:
+                do not plot results of statistical comparison of
                 each model performance against the lower-bound estimate of the
                 noise ceiling
-            True (default): plot results of statistical comparison of each
+
+            True (default):
+                plot results of statistical comparison of each
                 model performance against the lower-bound estimate of the noise
                 ceiling using default settings ('dewdrops')
-            'dewdrops': use circular "dewdrops" at the lower bound of the
+
+            'dewdrops':
+                use circular "dewdrops" at the lower bound of the
                 noise ceiling to indicate models whose performance is
                 significantly below the lower-bound estimate of the noise
                 ceiling
-            'icicles': use triangular "icicles" at the lower bound of the noise
+
+            'icicles':
+                use triangular "icicles" at the lower bound of the noise
                 ceiling to indicate models whose performance is significantly
                 below the lower-bound estimate of the noise ceiling
+
             Tests are one-sided, use the global alpha threshold and are
             automatically Bonferroni-corrected for the number of models tested.
+
         error_bars (Boolean or string):
-            False or None: do not plot error bars
-            True (default) or 'SEM': plot the standard error of the mean
-            'CI': plot 95%-confidence intervals (exluding 2.5% on each side)
-            'CI[x]': plot x%-confidence intervals
-                    (exluding (100-x)/2% on each side)
-                    i.e. 'CI' has the same effect as 'CI95'
+
+            False or None:
+                do not plot error bars
+
+            True (default) or 'SEM':
+                plot the standard error of the mean
+
+            'CI':
+                plot 95%-confidence intervals (exluding 2.5% on each side)
+
+            'CI[x]':
+                plot x%-confidence intervals
+                (exluding (100-x)/2% on each side)
+                i.e. 'CI' has the same effect as 'CI95'
+
             Confidence intervals are based on the bootstrap procedure,
             reflecting variability of the estimate across subjects and/or
             experimental conditions.
+
         test_type (string):
             which tests to perform:
-                't-test' : performs a t-test based on the variance estimates
-                    in the result structs
-                'bootstrap' : performs a bootstrap test, i.e. checks based
-                    on the number of samples defying H0
-                'ranksum' : performs wilcoxon signed rank sum tests
+
+            't-test':
+                performs a t-test based on the variance estimates
+                in the result structs
+
+            'bootstrap':
+                performs a bootstrap test, i.e. checks based
+                on the number of samples defying H0
+
+            'ranksum':
+                performs wilcoxon signed rank sum tests
 
     Returns:
         ---
@@ -161,7 +231,7 @@ def plot_model_comparison(result, sort=False, colors=None,
                           + 'provide uncertainty estimate')
             error_bars = False
     else:
-        while (len(evaluations.shape) > 2):
+        while len(evaluations.shape) > 2:
             evaluations = np.nanmean(evaluations, axis=-1)
         evaluations = evaluations[~np.isnan(evaluations[:, 0])]
         n_bootstraps, n_models = evaluations.shape
@@ -452,10 +522,14 @@ def plot_nili_bars(axbar, significant, version=1):
 
     Args:
         axbar: Matplotlib axes handle to plot in
+
         significant: Boolean matrix of model comparisons
-        version: 1 (Normal Nili bars, indicating significant differences)
-                 2 (Negative Nili bars in gray, indicating nonsignificant
-                    comparison results)
+
+        version:
+
+            - 1 (Normal Nili bars, indicating significant differences)
+            - 2 (Negative Nili bars in gray, indicating nonsignificant
+              comparison results)
 
     Returns:
         ---
@@ -501,15 +575,17 @@ def plot_golan_wings(axbar, significant, perf, sort, colors=None,
     Args:
         axbar: Matplotlib axes handle to plot in
         significant: Boolean matrix of model comparisons
-        version: 0 (single wing: solid circle anchor and open circles),
-                 1 (single wing: tick anchor and circles),
-                 2 (single wing: circle anchor and up and down feathers)
-                 3 (double wings: circle anchor,
-                    downward dominance-indicating feathers,
-                    from bottom to top in model order)
-                 4 (double wings: circle anchor,
-                    downward dominance-indicating feathers,
-                    from bottom to top in performance order)
+        version:
+
+            - 0 (single wing: solid circle anchor and open circles),
+            - 1 (single wing: tick anchor and circles),
+            - 2 (single wing: circle anchor and up and down feathers)
+            - 3 (double wings: circle anchor,
+              downward dominance-indicating feathers,
+              from bottom to top in model order)
+            - 4 (double wings: circle anchor,
+              downward dominance-indicating feathers,
+              from bottom to top in performance order)
 
     Returns:
         ---
@@ -529,8 +605,7 @@ def plot_golan_wings(axbar, significant, perf, sort, colors=None,
         plt.gcf().dpi_scale_trans.inverted())
     h_inch = bbox.height
     h = 1
-    for wo_i in range(len(wing_order)):
-        i = wing_order[wo_i]
+    for wo_i, i in enumerate(wing_order):
         if version in [3, 4]:
             js = np.concatenate((wing_order[0:wo_i],
                                  wing_order[wo_i+1:])).astype('int')
@@ -548,8 +623,7 @@ def plot_golan_wings(axbar, significant, perf, sort, colors=None,
         colors = np.tile([0, 0, 0, 1], (n_models, 1))
     tick_length_inch = 0.08
     k = 1
-    for wo_i in range(len(wing_order)):
-        i = wing_order[wo_i]
+    for wo_i, i in enumerate(wing_order):
         if version in [3, 4]:
             js = np.concatenate((wing_order[0:wo_i],
                                  wing_order[wo_i+1:])).astype('int')
@@ -740,9 +814,11 @@ def plot_arrows(axbar, significant):
 
 
 def draw_hor_arrow(ax, x1, x2, y, style, ah_L, ah_R):
-    # Draws a horizontal arrow from (x1, y) to (x2, y) if style is '->' and
-    # in the reverse direction if style is '<-'. If style is '<->', this
-    # function draws a double arrow.
+    """
+    Draws a horizontal arrow from (x1, y) to (x2, y) if style is '->' and
+    in the reverse direction if style is '<-'. If style is '<->', this
+    function draws a double arrow.
+    """
     lw, s = 1.6, 0.45
     ms, ms_a = 8, 18
     if (x1 < x2 and style == '->') or (x2 < x1 and style == '<-'):
